// $Id: palettedialog.h,v 1.5 2003/05/19 17:44:07 mlaurent Exp $

#ifndef PALETTEDIALOG_H
#define PALETTEDIALOG_H

#include <kdialogbase.h>

class paletteWidget;
class QPixmap;

class paletteDialog : public KDialogBase
{
  Q_OBJECT

public:
  paletteDialog(QPixmap *, QWidget *parent= 0, const char *name= 0);
  QPixmap *pixmap() const;
private:
  paletteWidget *pal;
};


#endif // PALETTEDIALOG_H


